@@ -345,15 +345,21 @@ class Extractor:
             year = res.group(1)
             number = res.group(2)
         else:
-            res = re.search('[第]?\s*([0-9]+)\s*(号|号文|期)?', query)
+            res = re.search('[〔\[\(［]\s*([0-9]{4})\s*[〕\]\)］]\s*([0-9]+)', query)
             if res:
                 final_res["document_no_full"] += res.group(0)
-                number = res.group(1)
+                year = res.group(1)
+                number = res.group(2)
             else:
-                res = re.search('[（\(][0-9]{6}[\)）]', query)
+                res = re.search('[第]?\s*([0-9]+)\s*(号|号文|期)', query)
                 if res:
                     final_res["document_no_full"] += res.group(0)
                     number = res.group(1)
+                else:
+                    res = re.search('[（\(]([0-9]{6})[\)）]', query)
+                    if res:
+                        final_res["document_no_full"] += res.group(0)
+                        number = res.group(1)
 
         res = re.search('[a-zA-Z]+/[a-zA-Z]+\s*[0-9]+(\.[0-9]+)?[—-][0-9]{4}', query)
         if res:
